@@ -51,8 +51,13 @@ private:
     QWidget *parent;
     DetailResultInfo searchDetails;
 
+    void addToCalendar(CCalendar *calendar);
+
+public:
+    void addToDefaultCalendar();
+
 private slots:
-    void addToCalendar();
+    void addToCalendarClicked();
 
 signals:
 
