@@ -39,6 +39,7 @@ ResultInfo parserMobileBahnDe::parseJourneyData(QByteArray data)
     QBuffer readBuffer;
 
     QString element = data;
+    qDebug() << "parserMobileBahnDe::parseJourneyData(): pre html" << endl << element;
 
     //Remove misformed html
     QRegExp ahrefReg = QRegExp("class=\"arrowlink\" href=\"(.*)\"");
@@ -46,56 +47,76 @@ ResultInfo parserMobileBahnDe::parseJourneyData(QByteArray data)
     element.replace(ahrefReg, "");
 
     element.replace("<img src=\"/v/760/img/achtung_rot_16x16.gif\" />", "<img src=\"/v/760/img/achtung_rot_16x16.gif\" />" + tr("Warning"));
+    #if 1
+        ahrefReg = QRegExp("<script.*</script>");
+        ahrefReg.setMinimal(true);
+        element.replace(ahrefReg, "");
 
+        /*ahrefReg = QRegExp("<ul class=\"neben \">");
+        ahrefReg.setMinimal(true);
+        element.replace(ahrefReg, "<ul><ul class=\"neben \">");*/
+    #endif
+
+        qDebug() << "parserMobileBahnDe::parseJourneyData(): post html" << endl << element;
     readBuffer.setData(element.toAscii());
     readBuffer.open(QIODevice::ReadOnly);
 
     QXmlQuery query;
     query.bindVariable("path", &readBuffer);
     //Query for Header infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/div[@class='haupt']/span[@class='bold']/string()");
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/div[@class='haupt']/span[@class='bold']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/div/div[@class='stdpadding editBtnCon paddingleft ']/span/string()");
 
     QStringList headerResults;
     if (!query.evaluateTo(&headerResults))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 1 Failed";
     }
+    qDebug() << "headerResults" << endl << headerResults;
 
     //Query for Time infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview timelink']/descendant::text()/string()");
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview timelink']/descendant::text()/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/table/tr/td[@class='overview timelink']/descendant::text()/string()");
 
     QStringList timelinkResults;
     if (!query.evaluateTo(&timelinkResults))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 2 Failed";
     }
+    qDebug() << "timelinkResults" << endl << timelinkResults;
 
     //Query for state infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview tprt']/string()");
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview tprt']/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/table/tr/td[@class='overview tprt']/string()");
 
     QStringList stateResults;
     if (!query.evaluateTo(&stateResults))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 3 Failed";
     }
+    qDebug() << "stateResults" << endl << stateResults;
 
-    //Query for chanes infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview']/descendant::text()/string()");
+    //Query for changes infos
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview']/descendant::text()/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/table/tr/td[@class='overview']/descendant::text()/string()");
 
     QStringList changesResults;
     if (!query.evaluateTo(&changesResults))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 4 Failed";
     }
+    qDebug() << "changeResults" << endl << changesResults;
 
     //Query for train infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview iphonepfeil']/descendant::text()[1]/string()");
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview iphonepfeil']/descendant::text()[1]/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/table/tr/td[@class='overview iphonepfeil']/descendant::text()[1]/string()");
 
     QStringList trainResults;
     if (!query.evaluateTo(&trainResults))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 5 Failed";
     }
+    qDebug() << "trainResults" << endl << trainResults;
 
     //Query for error infos
     query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/form/div[@class='fline errormsg']/string()");
@@ -105,24 +126,29 @@ ResultInfo parserMobileBahnDe::parseJourneyData(QByteArray data)
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 6 Failed";
     }
+    qDebug() << "errorsResults" << endl << errorsResults;
 
     //Query for later url
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/ul[@class='neben']/li/a[@class='noBG']/@href/string()");
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/ul[@class='neben']/li/a[@class='noBG']/@href/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/ul/ul[@class='neben']/li/a[@class='noBG']/@href/string()");
 
     QStringList laterUrl;
     if (!query.evaluateTo(&laterUrl))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 7 Failed";
     }
+    qDebug() << "laterUrl" << endl << laterUrl;
 
     //Query for Details Link infos
-    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview timelink']/a/@href/string()");
+    //query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/table/tr/td[@class='overview timelink']/a/@href/string()");
+    query.setQuery("declare default element namespace \"http://www.w3.org/1999/xhtml\"; declare variable $path external; doc($path)/html/body/div/div/div/table/tr/td[@class='overview timelink']/a/@href/string()");
 
     QStringList detailslinkResults;
     if (!query.evaluateTo(&detailslinkResults))
     {
         qDebug() << "parserMobileBahnDe::parseJourneyData - Query 8 Failed";
     }
+    qDebug() << "detailslinkResults" << endl << detailslinkResults;
 
     ResultInfo result;
 
@@ -642,6 +668,17 @@ ResultInfo parserMobileBahnDe::getJourneyData(QString destinationStation, QStrin
     ahrefReg.setMinimal(true);
     element.replace(ahrefReg, "");
 
+    #if 1
+        ahrefReg = QRegExp("<script.*</script>");
+        ahrefReg.setMinimal(true);
+        element.replace(ahrefReg, "");
+
+        /*ahrefReg = QRegExp("<ul class=\"neben \">");
+        ahrefReg.setMinimal(true);
+        element.replace(ahrefReg, "<ul><ul class=\"neben \">");*/
+    #endif
+
+
     //Check if we need do a search by id, sometimes the search for the exact name
     //returns a selectbox again, so we check for it and if there are selectboxes
     //we search by the ids we get as response
